@@ -1,7 +1,7 @@
 /***************************************************************************
                       codegenerator.cpp  -  description
                              -------------------
-    copyright            : (C) 2007-2019 by Andre Simon
+    copyright            : (C) 2007-2020 by Andre Simon
     email                : a.simon@mailbox.org
  ***************************************************************************/
 
@@ -190,6 +190,10 @@ void CodeGenerator::setTitle(const string & title)
 {
     if (!title.empty())
         docTitle= title;
+    std::size_t found = docTitle.rfind("/");
+    if (found!=std::string::npos){
+        docTitle = docTitle.substr(found+1);
+    }
 }
 
 string CodeGenerator::getTitle()
@@ -1110,12 +1114,12 @@ void CodeGenerator::processInput()
         sleep(1);
         #endif
       } else {
-        if (!parseCP437 && !omitTrailingCR) *out << newLineTag;
+        if (!parseCP437 && !omitTrailingCR) printNewLine(outputType!=TEXT);
         break;
       }
     } else {
         
-      if (!omitNewLine && !parseCP437 && lineNumber>1) *out << newLineTag;  
+      if (!omitNewLine && !parseCP437 && lineNumber>1) printNewLine();  
      
       if (!omitNewLine ) insertLineNumber();
       omitNewLine = false;
@@ -1172,28 +1176,33 @@ void CodeGenerator::processInput()
             ++i;
           }  
         } else {
-            
+
+          if ( (cur&0xff)==0x0d && i<line.length()-1) {
+            plainTxtCnt-=i;
+
+            lineBuf.seekp(showLineNumbers ? 0 : 0, ios::beg);
+            lineBuf<<getOpenTag();
+          }
             // wrap line
           if (lineWrapLen && plainTxtCnt && plainTxtCnt % lineWrapLen==0) {
               ++lineNumber;
-              *out << newLineTag; 
+              printNewLine(); 
               insertLineNumber();
               plainTxtCnt=0;
            }
-          
-          
+
           if ( line.length() - i > 2 && (line[i+1]&0xff)==0x08) i++;  
           if ( cur==0x07) {
               ++lineNumber;
-              *out << newLineTag;  
+              printNewLine();  
               insertLineNumber();
         }  
-  
+
           if ( cur==0x1b || (!ignCSISeq && ( cur==0x9b || cur==0xc2)) ) {
 
-            if (line.length() - i > 2){              
+            if (line.length() - i > 2){
               next = line[i+1]&0xff;
-              
+
               //move index behind CSI
               if ( (cur==0x1b && next==0x5b) || ( cur==0xc2 && next==0x9b) ) {
                   ++i;
@@ -1201,12 +1210,12 @@ void CodeGenerator::processInput()
                   // restore a unicode sequence if the two digit CSI is not matched
                   // ansiweather -l Berlin,DE | ansifilter -T
                   if (cur==0xc2 || cur==0x1b) {
-                      *out << maskCharacter(cur);
+                      lineBuf << maskCharacter(cur);
                       ++plainTxtCnt;
                 }
 
               }
-              
+
               // http://linuxcommand.org/lc3_adv_tput.php
               // http://ascii-table.com/ansi-escape-sequences-vt-100.php
               if (next==0x28){ // ( -> maybe need to handle more codes here
@@ -1223,17 +1232,17 @@ void CodeGenerator::processInput()
                 //find sequence end
                 while (   seqEnd<line.length() 
                   && (line[seqEnd]<0x40 || line[seqEnd]>0x7e )) {
-                    ++seqEnd;                    
+                    ++seqEnd;
                   }
                   
                   if (   line[seqEnd]=='m' && !ignoreFormatting ) {
                     if (!elementStyle.isReset()) {
-                      *out <<getCloseTag();
+                      lineBuf <<getCloseTag();
                       tagOpen=false;
                     }
                     parseSGRParameters(line, i, seqEnd);
                     if (!elementStyle.isReset()) {
-                      *out <<getOpenTag();
+                      lineBuf <<getOpenTag();
                       tagOpen=true;
                     }
                   }
@@ -1254,14 +1263,10 @@ void CodeGenerator::processInput()
               } else {
                 cur= line[i-1]&0xff;
                 next = line[i]&0xff;
-                
 
                 //ignore content of two and single byte sequences (no CSI)
                 if (cur==0x1b && (  next==0x50 || next==0x5d || next==0x58
-                  || next==0x5e||next==0x5f 
-                  // || next==0x37 || next==0x38
-                    
-                ) ) // DECSC seq
+                  || next==0x5e||next==0x5f ) ) // DECSC seq
                 {
                   seqEnd=i;
                   //find string end
@@ -1300,21 +1305,18 @@ void CodeGenerator::processInput()
               if (seqEnd<line.length() ) {
                   i=seqEnd+1;
               } else {
-                *out << maskCharacter(line[i]);
+                lineBuf << maskCharacter(line[i]);
                 ++i;
                 ++plainTxtCnt;
               }
           } else {
             // output printable character
-            *out << maskCharacter(line[i]);
+            lineBuf << maskCharacter(line[i]);
             ++i;
             ++plainTxtCnt;
           }
-          
-          
         }
       }
-      //if (!parseCP437 && !omitTrailingCR) *out << newLineTag;
     }
   } // while (true)
   
@@ -1328,6 +1330,21 @@ void CodeGenerator::processInput()
   out->flush();
 }
 
+
+void CodeGenerator::printNewLine(bool eof) {
+
+    string lineStr(lineBuf.str());
+    if (eof) {
+        lineStr = lineStr.substr(0, lineBuf.tellp());
+    }
+    *out << lineStr;
+    *out << newLineTag;
+
+    lineBuf.clear();
+    lineBuf.str(std::string());
+}
+
+
 /* the following functions are based on Wolfgang Frischs xterm256 converter utility:
    http://frexx.de/xterm-256-notes/
 */
